import React, { useState } from "react";
import { Files, Share, Settings, LogOut } from "lucide-react";
import { FilesComponent } from "./FileComponent";
import { SettingsComponent } from "./Settings";
import { SharesComponent } from "./ShareComponent";

interface MainPageProps {
  isDarkMode: boolean;
  onLogout: () => void;
  onThemeToggle: () => void;
}

interface GradientColors {
  dark: { from: string; to: string };
  light: { from: string; to: string };
}

export const MainPage: React.FC<MainPageProps> = ({ 
  isDarkMode, 
  onLogout, 
  onThemeToggle 
}) => {
  const [activeView, setActiveView] = useState<'files' | 'shares' | 'settings'>('files');
  const [gradientColors, setGradientColors] = useState<GradientColors>({
    dark: { from: '#7b2ff7', to: '#f107a3' },
    light: { from: '#06b6d4', to: '#3b82f6' }
  });

  const currentGradient = isDarkMode ? gradientColors.dark : gradientColors.light;
  const gradientStyle = {
    background: `linear-gradient(135deg, ${currentGradient.from} 0%, ${currentGradient.to} 100%)`
  };

  const renderActiveView = () => {
    console.log('isDarkMode:', isDarkMode);
    switch (activeView) {
      case 'files':
        return <FilesComponent isDarkMode={isDarkMode} />;
      case 'shares':
        return <SharesComponent isDarkMode={isDarkMode} />;
      case 'settings':
        return (
          <SettingsComponent 
            isDarkMode={isDarkMode} 
            onThemeToggle={onThemeToggle}
            gradientColors={gradientColors}
            setGradientColors={setGradientColors}
          />
        );
      default:
        return <FilesComponent isDarkMode={isDarkMode} />;
    }
  };

  return (
    <div className="app-container" style={gradientStyle}>
      <div className="app-layout">
        {/* Sidebar */}
        <div className={`sidebar ${isDarkMode ? 'sidebar-dark' : 'sidebar-light'}`}>
          <h2 className={`sidebar-title ${isDarkMode ? 'text-white' : 'text-gray-800'}`}>
            LiteCloud
          </h2>
          
          <nav className="sidebar-nav">
            <button
              onClick={() => setActiveView('files')}
              className={`nav-button ${
                activeView === 'files'
                  ? isDarkMode ? 'nav-button-active-dark' : 'nav-button-active-light'
                  : isDarkMode ? 'nav-button-inactive-dark' : 'nav-button-inactive-light'
              }`}
            >
              <Files size={20} />
              My Files
            </button>
            
            <button
              onClick={() => setActiveView('shares')}
              className={`nav-button ${
                activeView === 'shares'
                  ? isDarkMode ? 'nav-button-active-dark' : 'nav-button-active-light'
                  : isDarkMode ? 'nav-button-inactive-dark' : 'nav-button-inactive-light'
              }`}
            >
              <Share size={20} />
              Shares
            </button>
            
            <button
              onClick={() => setActiveView('settings')}
              className={`nav-button ${
                activeView === 'settings'
                  ? isDarkMode ? 'nav-button-active-dark' : 'nav-button-active-light'
                  : isDarkMode ? 'nav-button-inactive-dark' : 'nav-button-inactive-light'
              }`}
            >
              <Settings size={20} />
              Settings
            </button>
          </nav>
          
          <div className="sidebar-footer">
            <button
              onClick={onLogout}
              className="logout-button-sidebar"
            >
              <LogOut size={20} />
              Logout
            </button>
          </div>
        </div>

        {/* Main Content */}
        <div className={`main-content ${isDarkMode ? 'main-content-dark' : 'main-content-light'}`}>
          {renderActiveView()}
        </div>
      </div>
    </div>
  );
};